@@ -1,4 +1,4 @@
-from pyrustic.viewable import Viewable
+from viewable import Viewable
 import math
 import traceback
 import tkinter as tk
@@ -6,6 +6,7 @@ import tkinter as tk
 
 class Toolbar(Viewable):
     def __init__(self, node_id, parent, callback, log_window_builder):
+        super().__init__()
         self._node_id = node_id
         self._parent = parent
         self._callback = callback
@@ -271,7 +272,7 @@ class Toolbar(Viewable):
     #       VIEWABLE METHODS IMPLEMENTATION
     # ========================================
 
-    def _on_build(self):
+    def _build(self):
         self._body = tk.Frame(self._parent, name="runtestToolbar")
         self._body.grid(pady=5, sticky="w")
         # ============== frames ================
@@ -409,11 +410,6 @@ class Toolbar(Viewable):
         self._install_default_widgets()
         return self._body
 
-    def _on_display(self):
-        pass
-
-    def _on_destroy(self):
-        pass
 
     # ========================================
     #             PRIVATE METHODS
